==> Botan-1.1.10.tgz: Botan-1.1.10/src/x509opt.cpp <==
/*************************************************
* X.509 Certificate Options Source File          *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#include <botan/x509opt.h>
#include <botan/conf.h>
#include <ctime>

namespace Botan {

/*************************************************
* Set information stored in the subject field    *
*************************************************/
void X509_Cert_Options::set_name(const std::string& s) { name = s; }
void X509_Cert_Options::set_country(const std::string& s) { country = s; }
void X509_Cert_Options::set_org(const std::string& s) { org = s; }
void X509_Cert_Options::set_org_unit(const std::string& s) { org_unit = s; }
void X509_Cert_Options::set_locality(const std::string& s) { locality = s; }
void X509_Cert_Options::set_state(const std::string& s) { state = s; }

/*************************************************
* Set AlternativeNames options                   *
*************************************************/
void X509_Cert_Options::set_email(const std::string& s) { email = s; }
void X509_Cert_Options::set_dns_name(const std::string& s) { dns = s; }
void X509_Cert_Options::set_uri(const std::string& s) { uri = s; }

/*************************************************
* Set information stored in the validity field   *
*************************************************/
void X509_Cert_Options::set_validity_start(const std::string& time_string)
   {
   start = X509_Time(time_string);
   }

void X509_Cert_Options::set_validity_end(const std::string& time_string)
   {
   end = X509_Time(time_string);
   }

/*************************************************
* Set key constraint information                 *
*************************************************/
void X509_Cert_Options::set_constraints(Key_Constraints usage)
   {
   constraints = usage;
   }

void X509_Cert_Options::add_ex_constraints(const OID& oid)
   {
   ex_constraints.push_back(oid);
   }

/*************************************************
* Mark this certificate for CA usage             *
*************************************************/
void X509_Cert_Options::CA_key(u32bit limit)
   {
   is_ca = true;
   path_limit = limit;
   }

/*************************************************
* Do basic sanity checks                         *
*************************************************/
void X509_Cert_Options::sanity_check() const
   {
   if(name == "" || country == "")
      throw Encoding_Error("X.509 certificate: name and country MUST be set");
   if(country.size() != 2)
      throw Encoding_Error("Invalid ISO country code: " + country);
   if(start >= end)
      throw Encoding_Error("X509_Cert_Options: invalid time constraints");
   }

/*************************************************
* Initialize the certificate options             *
*************************************************/
X509_Cert_Options::X509_Cert_Options(const std::string& initial_opts)
   {
   const u32bit DEFAULT_EXPIRE = Config::get_time("x509/ca/default_expire");

   self_signed = is_ca = false;
   path_limit = 0;
   constraints = NO_CONSTRAINTS;

   start = X509_Time(system_time() - 30);
   end = X509_Time(system_time() + DEFAULT_EXPIRE);

   if(initial_opts == "")
      return;

   std::vector<std::string> parsed = split_on(initial_opts, '/');

   if(parsed.size() > 4)
      throw Invalid_Argument("X.509 cert options: Too many names: "
                             + initial_opts);

   if(parsed.size() >= 1) set_name(parsed[0]);
   if(parsed.size() >= 2) set_country(parsed[1]);
   if(parsed.size() >= 3) set_org(parsed[2]);
   if(parsed.size() == 4) set_org_unit(parsed[3]);
   }

}

==> Botan-1.1.11.tgz: Botan-1.1.11/src/x509opt.cpp <==
/*************************************************
* X.509 Certificate Options Source File          *
* (C) 1999-2003 The Botan Project                *
*************************************************/

#include <botan/x509opt.h>
#include <botan/conf.h>
#include <ctime>

namespace Botan {

/*************************************************
* Set when the certificate should become valid   *
*************************************************/
void X509_Cert_Options::not_before(const std::string& time_string)
   {
   start = X509_Time(time_string);
   }

/*************************************************
* Set when the certificate should expire         *
*************************************************/
void X509_Cert_Options::not_after(const std::string& time_string)
   {
   end = X509_Time(time_string);
   }

/*************************************************
* Set key constraint information                 *
*************************************************/
void X509_Cert_Options::add_constraints(Key_Constraints usage)
   {
   constraints = usage;
   }

/*************************************************
* Set key constraint information                 *
*************************************************/
void X509_Cert_Options::add_ex_constraint(const OID& oid)
   {
   ex_constraints.push_back(oid);
   }

/*************************************************
* Mark this certificate for CA usage             *
*************************************************/
void X509_Cert_Options::CA_key(u32bit limit)
   {
   is_CA = true;
   path_limit = limit;
   }

/*************************************************
* Do basic sanity checks                         *
*************************************************/
void X509_Cert_Options::sanity_check() const
   {
   if(common_name == "" || country == "")
      throw Encoding_Error("X.509 certificate: name and country MUST be set");
   if(country.size() != 2)
      throw Encoding_Error("Invalid ISO country code: " + country);
   if(start >= end)
      throw Encoding_Error("X509_Cert_Options: invalid time constraints");
   }

/*************************************************
* Initialize the certificate options             *
*************************************************/
X509_Cert_Options::X509_Cert_Options(const std::string& initial_opts)
   {
   const u32bit DEFAULT_EXPIRE = Config::get_time("x509/ca/default_expire");

   is_CA = false;
   path_limit = 0;
   constraints = NO_CONSTRAINTS;

   const u64bit current_time = system_time();

   start = X509_Time(current_time - 30);
   end = X509_Time(current_time + DEFAULT_EXPIRE);

   if(initial_opts == "")
      return;

   std::vector<std::string> parsed = split_on(initial_opts, '/');

   if(parsed.size() > 4)
      throw Invalid_Argument("X.509 cert options: Too many names: "
                             + initial_opts);

   if(parsed.size() >= 1) common_name  = parsed[0];
   if(parsed.size() >= 2) country      = parsed[1];
   if(parsed.size() >= 3) organization = parsed[2];
   if(parsed.size() == 4) org_unit     = parsed[3];
   }

}
